polyfemos.back.main — polyfemos 0.3.29 documentation

# polyfemos.back.main

Backend of polyfemos

- reading data and state of health miniseeds and log files

- writing state of health meta files

    - stf

    - csv

    - alert

- Creating data coverage plots

- Plotting PPSD plots (not yet)

- Triggering seismic events + Beampacking (not yet)

The program is used by creating ‘*.conf’ files which define the program flow and values used.

See Backend for documentation.

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.back.main.` `main`(conffile)
  Parameters

    conffile (str) – Filepath of the conffile

`polyfemos.back.main.` `readconf`(argv=None)

  A function for reading ‘*.conf’ files from command line.

  Parameters

    argv (list) – command line arguments